from setuptools import setup

setup(name='Julia_distributions',
      version='0.1',
      description='Gaussian and Binominal distributions',
      packages=['Julia_distributions'],
      author = 'Julia',
      zip_safe=False)
